@@ -19,7 +19,7 @@ use Tags::HTML::Element::Textarea;
 Readonly::Array our @TEXT_KEYS => qw(add_comment author date save);
 Readonly::Scalar our $CSS_CLASS_ADD_COMMENT => 'add-comment';
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -89,6 +89,8 @@ sub new {
 	$self->{'_tags_textarea'} = Tags::HTML::Element::Textarea->new(%c);
 	my $data_textarea = Data::HTML::Element::Textarea->new(
 		'autofocus' => 1,
+		'id' => 'message_board_comment_message',
+		'name' => 'message_board_comment_message',
 		'rows' => 6,
 	);
 	$self->{'_tags_textarea'}->init($data_textarea);
@@ -98,6 +100,9 @@ sub new {
 		'data' => [
 			$self->_text('save'),
 		],
+		'name' => 'action',
+		'type' => 'submit',
+		'value' => 'add_message_board_comment',
 	);
 	$self->{'_tags_button'}->init($data_button);
 
@@ -692,6 +697,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
